#
# spec file for package python-qt4
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-qt4
Version:        4.12.3
Release:        lp152.1.4
Summary:        PyQt - python bindings for Qt 4
License:        SUSE-GPL-2.0-with-FLOSS-exception or GPL-3.0 or SUSE-NonFree
Group:          Development/Libraries/Python
Url:            http://www.riverbankcomputing.com/software/pyqt/intro
Source:         http://sourceforge.net/projects/pyqt/files/PyQt4/PyQt-%{version}/PyQt4_gpl_x11-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM: Fix .pro files not being generated by configure.py
Patch0:         pyqt4_add_pro_files.diff
# PATCH-FIX-UPSTREAM -- TODO
Patch1:         reproducible.patch
# PATCH-FIX-OPENSUSE
Patch2:         make-warnings-nonfatal.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module sip >= 4.19.1}
BuildRequires:  %{python_module sip-devel >= 4.19.1}
BuildRequires:  %{python_module sip < 5}
BuildRequires:  %{python_module sip-devel < 5}
BuildRequires:  dbus-1-devel
BuildRequires:  dbus-1-python-devel
BuildRequires:  dbus-1-python3-devel
BuildRequires:  fdupes
BuildRequires:  libqt4-devel
BuildRequires:  pkgconfig(phonon)
BuildRequires:  python-rpm-macros
Requires:       %{name}-utils
Requires:       python-sip(api) = %python_sip_api_ver
Provides:       python-PyQt4 = %{version}
%requires_ge    python-dbus-python
%requires_ge    libqt4-x11
%ifpython2
%requires_ge    dbus-1-python
%endif
%ifpython3
%requires_ge    dbus-1-python3
%endif

%python_subpackages

%description
PyQt is a set of Python bindings for Trolltech's Qt application
framework and runs on all platforms supported by Qt including Windows,
MacOS/X and Linux. There are two sets of bindings: PyQt v4 supports Qt
v4; and the older PyQt v3 supports Qt v3 and earlier. The bindings are
implemented as a set of Python modules and contain over 300 classes and
nearly 6,000 functions and methods.


%package devel
Summary:        PyQt - devel part of python bindings for Qt 4
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python-devel
%ifpython2
Requires:       dbus-1-python-devel
%endif
%ifpython3
Requires:       dbus-1-python3-devel
%endif
Requires:       libqt4-devel
Requires:       phonon-devel
Requires:       python-qt4-utils = %{version}
Requires:       python-sip-devel >= 4.19.1
Recommends:     python-qscintilla
Provides:       python-PyQt4-devel = %{version}
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description devel
PyQt is a set of Python bindings for Trolltech's Qt application
framework and runs on all platforms supported by Qt including Windows,
MacOS/X and Linux. There are two sets of bindings: PyQt v4 supports Qt
v4; and the older PyQt v3 supports Qt v3 and earlier. The bindings are
implemented as a set of Python modules and contain over 300 classes and
nearly 6,000 functions and methods.

This package contains all the developer tools you need to create your
own PyQt applications.


%package -n %{name}-utils
Summary:        Common files for PyQt4 for python2 and python3
Group:          Development/Libraries/Python
Provides:       %{python_module PyQt4-utils = %{version}}
Provides:       %{python_module qt4-utils = %{version}}

%description -n %{name}-utils
PyQt is a set of Python bindings for Trolltech's Qt application
framework and runs on all platforms supported by Qt including Windows,
MacOS/X and Linux. There are two sets of bindings: PyQt v4 supports Qt
v4; and the older PyQt v3 supports Qt v3 and earlier. The bindings are
implemented as a set of Python modules and contain over 300 classes and
nearly 6,000 functions and methods.

This package contains common files shared between python2 and python3
versions of PyQt4.


%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Provides:       %{python_module PyQt4-doc = %{version}}
Provides:       %{python_module qt4-doc = %{version}}

%description -n %{name}-doc
PyQt is a set of Python bindings for Trolltech's Qt application
framework and runs on all platforms supported by Qt including Windows,
MacOS/X and Linux. There are two sets of bindings: PyQt v4 supports Qt
v4; and the older PyQt v3 supports Qt v3 and earlier. The bindings are
implemented as a set of Python modules and contain over 300 classes and
nearly 6,000 functions and methods.

This package contains documentation and examples for PyQt4.


%prep
%autosetup -p1 -n PyQt4_gpl_x11-%{version}
# Fix wrong-script-interpreter
find examples -name "*.py" -exec sed -i "s|^#!/usr/bin/env python$|#!%__python3|" {} \;

%build
export CXXFLAGS="%{optflags}"
export CFLAGS="%{optflags}"

%{python_expand mkdir build_%{$python_bin_suffix}
pushd build_%{$python_bin_suffix}

$python ../configure-ng.py --verbose \
                           --confirm-license \
                           --qsci-api \
                           --debug \
                           --sip=%{_bindir}/sip-%{$python_bin_suffix}

make %{?_smp_mflags}

popd

}

%install
mkdir -p %{buildroot}%{_sysconfdir}/alternatives

%{python_expand pushd build_%{$python_bin_suffix}

%make_install INSTALL_ROOT=%{buildroot}

# Point to the correct location for the documentation files
cp ../README ./
sed -i 's/The "doc" directory/The "doc" directory of package %{$python_prefix}-qt4-devel/' README

popd

mv %{buildroot}%{_libdir}/qt4/plugins/designer/libpyqt4.so %{buildroot}%{_libdir}/qt4/plugins/designer/libpy%{$python_bin_suffix}qt4.so
mv -T %{buildroot}%{_datadir}/qt4/qsci/api/python %{buildroot}%{_datadir}/qt4/qsci/api/python_%{$python_bin_suffix}

%fdupes %{buildroot}%{python_sitearch}
}

mkdir -p %{buildroot}%{_docdir}/%{name}
cp -r doc %{buildroot}%{_docdir}/%{name}/
cp -r examples %{buildroot}%{_docdir}/%{name}/
%fdupes %{buildroot}%{_docdir}/%{name}/

%python_clone -a %{buildroot}%{_bindir}/pyuic4
%python_clone -a %{buildroot}%{_bindir}/pylupdate4
%python_clone -a %{buildroot}%{_bindir}/pyrcc4

%post devel
%{python_install_alternative pyuic4 pylupdate4 pyrcc4}

%preun devel
%python_uninstall_alternative pyuic4

%files %{python_files}
%defattr(-,root,root)
%doc build_%{python_bin_suffix}/README
%doc ChangeLog LICENSE NEWS THANKS 
%{python_sitearch}/PyQt4/
%{python_sitelib}/dbus/mainloop/qt.so
%exclude %{_docdir}/%{name}/doc/
%exclude %{_docdir}/%{name}/examples/

%files %{python_files devel}
%defattr(-,root,root)
%doc LICENSE
%python_alternative %{_bindir}/pyuic4
%python_alternative %{_bindir}/pylupdate4
%python_alternative %{_bindir}/pyrcc4
%{_libdir}/qt4/plugins/designer/libpy%{python_bin_suffix}qt4.so
%dir %{_datadir}/qt4/qsci/
%dir %{_datadir}/qt4/qsci/api/
%dir %{_datadir}/qt4/qsci/api/python_%{python_bin_suffix}/
%{_datadir}/qt4/qsci/api/python_%{python_bin_suffix}/PyQt4.api

%files -n %{name}-utils
%defattr(-,root,root)
%doc LICENSE
%{_datadir}/sip/PyQt4/

%files -n %{name}-doc
%defattr(-,root,root)
%doc LICENSE
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/doc/
%{_docdir}/%{name}/examples/

%changelog
* Mon Oct 14 2019 Fabian Vogt <fvogt@suse.com>
- Add patch to fix build:
  * make-warnings-nonfatal.patch
* Sat Dec  8 2018 Todd R <toddrme2178@gmail.com>
- Remove QtWebkit again.
* Fri Dec  7 2018 Todd R <toddrme2178@gmail.com>
- Update to version 4.12.3
  - This is planned to be the last ever release of PyQt4.
  - Bug fixes.
- Update to version 4.12.2
  - A private copy of the sip module called PyQt4.sip is required.
  - SIP v4.19.12 is now required.  SIP v5 is not supported.
- Fix python2 version calling python3 version.
- Build QtWebkit bindings, needed by some packages (e.g. Spyder)
* Sat Dec  2 2017 fabian@ritter-vogt.de
- Do not build with Qt4 WebKit:
  * Vade retro satana
* Tue Aug 29 2017 toddrme2178@gmail.com
- Fix shebangs
* Mon Aug 28 2017 toddrme2178@gmail.com
- Update to 4.12.1
  * SIP v4.19.1 is now required.
  * Bug fixes.
* Sun Jun  4 2017 antoine.belvire@opensuse.org
- Move requirements for development package to correct place.
* Mon May 22 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build fully reproducible
* Tue May 16 2017 toddrme2178@gmail.com
- Fix issues with requires.
  Fixes bnc#1037475
* Thu May  4 2017 toddrme2178@gmail.com
- Fix issues with update-alternatives.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Remove unneeded link-python.diff and link-python3.diff.
* Wed Mar 29 2017 toddrme2178@gmail.com
- Temporarily undo some of the single spec changes to allow building
  until a newer python-dbus is available
* Mon Mar  6 2017 toddrme2178@gmail.com
- Switch to single-spec version.
- Add rpmlintrc with doc-file-dependency to handle the example
  files.
- Switch to using configure-ng.py for all versions.
- Remove unneeded link-python.diff
- Use update-alternatives for all executables.  As a result,
  executables have been moved to the -devel subpackage.
* Thu Feb 16 2017 termim@gmail.com
- Require sip 4.19.1 for compatibility with PyQt5
* Tue Jan  3 2017 termim@gmail.com
- Update to 4.12
  - SIP v4.19 is now required.
  - Bug fixes.
* Fri Aug 14 2015 termim@gmail.com
- Remove build-compare.diff as already in upstream
* Fri Aug 14 2015 termim@gmail.com
- change required sip version to 4.16.9
* Sat Jun 13 2015 termim@gmail.com
- Update to 4.11.4
  - This is a minor functional and bug-fix release including support for Qt
  - v4.8.7.
* Tue Jan 27 2015 termim@gmail.com
- Update to 4.11.3
  - This is a bug-fix release.
* Sat Oct 11 2014 termim@gmail.com
- Update to 4.11.2
  - This is a bug-fix only release.
  - run spec-cleaner
* Sat Sep 20 2014 edogawa@aon.at
- tweaked python3-qt4.spec to also include the dbus support module
* Thu Jul 31 2014 toddrme2178@gmail.com
- Update to 4.11.1
  - Added the -tr-function, -trUtf8-function and -translate-function command
    line options to pylupdate4.
  - Bug fixes.
* Sun Jun 15 2014 lbeltrame@kde.org
- Add pyqt4_add_pro_files.diff: fix .pro files not being generated
  with configure.py
- Switch back to configure.py as -ng does not generate pyqtconfig4
  and that is needed by downstream projects (PyKDE4)
* Thu May 29 2014 termim@gmail.com
- Update to 4.11
  - By default a Python slot is only invoked if the underlying C++ instance
    still exists.
  - Added the no_receiver_check argument to connect().
  - Added support for Qt v4.8.6.
  - Added --target-py-version, --sysroot and --no-tools options to
    configure-ng.py.
  - Cross-compiling (specifically to iOS and Android when building against Qt
    v5) is now supported.
  - SIP v4.16 is now required.
  - Bug fixes.
* Sun Mar 23 2014 tittiatcoke@gmail.com
- Update to 4.10.4. This is a minor bug fix release
- Drop patch fix-phonon.diff due to upstream inclusion
* Fri Nov 15 2013 joseph@mulloy.me
- Fixed missing phonon support (bnc#848953)
  * Patched configure.py so that it properly detects phonon
* Wed Sep 11 2013 tittiatcoke@gmail.com
- Build issues are resolved with the Python KDE bindings.
  Python-sip is upgraded again to 4.15.1
* Fri Aug 30 2013 tittiatcoke@gmail.com
- Revert back to 4.10.2 due to the downgrade of python-sip
* Tue Aug 27 2013 termim@gmail.com
- Update to 4.10.3. This is a minor bug fix release.
* Thu Jun 27 2013 termim@gmail.com
- Update to 4.10.2
  * Bug fixes.
- Update to 4.10.1
  * Added support for QtCore.pyqtSetPickleProtocol() and
    QtCore.pyqtPickleProtocol() to set and get the protocol used to pickle
    Python objects when serialising them for Qt.
  * Added support for the --resource-suffix option to pyuic4.
  * Added a new build system (configure-ng.py) which will be compatible with
    SIP v5 and will eventually support cross-compilation.
  * Added support for Qt v5.0.2.
  * Bug fixes.
- remove disable-rpaths.diff
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Mar  4 2013 mlin@suse.com
- Update to 4.10
  * The focus of this release is on support for the final release of Qt v5.0.
- Update disable-rpaths.diff
* Sun Dec  9 2012 lbeltrame@kde.org
- Update to 4.9.6:
  - Added the missing constBits() and constScanLine() methods to QImage.
  - A QPoint can now be specified whenever a QPointF is expected.
  - Added support for Qt v4.8.4.
  - Added support for Qt v5.0-rc1 (QtCore, QtGui, QtHelp, QtNetwork, QtSql,
    QtSvg, QtWebKit and QtXml only).
  - Added the --no-deprecated option to configure.py.
  - SIP v4.14.2 is now required.
* Mon Oct  1 2012 einar@heavensinferno.net
- Update to the latest upstream version:
  - Added support for Qt v4.8.3.
  - Added support for Qt v5-beta1 (QtCore, QtGui, QtHelp, QtNetwork, QtSql,
    QtSvg, QtWebKit and QtXml only).
  - Implemented __str__ and __unicode__ for QChar.
  - Added the missing QPointF operator*(qreal, QPointF).
  - Added the customcompleter.py example.
  - SIP v4.14 is now required.
* Thu Jul  5 2012 dmueller@suse.com
- update to version 4.9.4:
  * bug fixes
- require the sip api version it was built against (bnc#768499)
* Fri Jun 22 2012 mlin@suse.com
- Update to version 4.9.2
  * Added support for Qt v4.8.2.
  * Added support for Qt v5-alpha (QtCore and QtGui only).
  * Added support for Python v3.3.
  * bool(QPyNullVariant(...)) now returns False rather than True to mimic the behaviour of None.
  * Exposed the pyqtBoundSignal type object in the QtCore module.
  * Added the signal attribute to pyqtBoundSignal containing the signature that would be returned by SIGNAL().
  * Added the optional package argument to uic.loadUi() to properly handle relative imports.
  * pyuic4 now supports themed icons.
  * Added the spreadsheet example from Hans-Peter Jansen.
* Mon Jun  4 2012 idonmez@suse.com
- Update license
* Mon May 28 2012 mlin@suse.com
- Fix files list
  * Added pyqtconfig.py back
* Fri May 25 2012 toddrme2178@gmail.com
- Update to version 4.9.1
  * Bugfixes
- Spec file cleanups
- Fixed licenses
* Sun Dec 25 2011 idonmez@suse.com
- Update to version 4.9
  * Fixed %%PickleCode for QByteArray for Python v3.
  * Completed the support for QPainter.drawPixmapFragments().
  * pyuic4 now makes sure that a module implementing a resource file is only
    imported once.
  * Fixed a regression in the handling of translated strings by pyuic4.
  * QDBusArgument now handles QStringList explicitly so that it can be used with
    QString v2 API.
  * Renamed QDBusArgument.write() to add().
  * Changed QDBusArgument.write() to use a QMetaType.Type to specify the integer
    sub-type to be consistent with beginArray() and beginMap().
  * Implemented QDBusArgument.write().
  * DBus dicts are now demarshalled to Python dicts.
  * Added support for demarshalling DBus basic types, variants and arrays.
  * QDBusObjectPath, QDBusSignal and QDBusVariant instances are now demarshalled
    automatically.
  * DBus structures are now demarshalled to tuples.
  * Added the missing cornerWidget() and setCornerWidget() methods to QMenuBar.
- See include ChangeLog for complete change list.
* Fri Nov 25 2011 cgiboudeaux@gmx.com
- Use %%make_install
* Mon Nov 21 2011 cgiboudeaux@gmx.com
- Update to 4.8.6, see http://riverbankcomputing.com/static/Downloads/PyQt4/ChangeLog
- Spec cleanup
* Tue Oct 18 2011 jdmulloy@gmail.com
- Added phonon-devel to BuildRequires in python-qt4.spec
  * Adds phonon support to python-qt4 which is required by programs like OpenLP.org
* Tue Aug 30 2011 idonmez@suse.com
- Remove check for obsolete openSUSE versions.
* Mon Aug 29 2011 termim@gmail.com
- Add python-qt4-utils package to avoid conflicts between python2
  and python3 versions
* Mon Aug 22 2011 idonmez@novell.com
- Unbreak -debuginfo package creation
* Tue Aug 16 2011 termim@gmail.com
- update to 4.8.5
  - This is a minor bug fix release.
* Tue May  3 2011 gregkh@suse.de
- fix for x86-64 issue to enable the package to properly build.
* Mon May  2 2011 dmueller@suse.de
- update to 4.8.4:
  * Added support for Qt v4.7.2.
  * Added limited support for setEventFilter() and filterEvent() to QAbstractEventDispatcher.
  * pyrcc4 will now compress by default to match the behaviour of rcc.
  * Removed QTouchEventSequence as its C++ API makes it impossible to be used from Python.
* Fri Feb 11 2011 coolo@novell.com
- refresh patches
* Tue Jan 25 2011 dmueller@suse.de
- update to 4.8.3:
  - Added the QPyNullVariant class to the QVariant v2 API to allow null
    QVariants to be implemented.
  - Added the optional type keyword argument to QSettings.value() to allow the
    type of the returned value to be specified.
  - QDeclarativeItem will now act as a transparent proxy from any QML signals
    and JavaScript functions.
  - Any QObject invokable methods can now be called transparently even if they
    haven't been explicitly wrapped.
  - QWizardPage.registerField() can now take an unbound or bound signal as its
    'changedSignal' argument.
  - Converted the Reference Guide to Sphinx.
  - Bug fixes.
* Mon Jan  3 2011 dmueller@suse.de
- update to 4.8.2:
  - Added support for Qt v4.7.1.
  - Added the coloreditorfactory.py, combowidgetmapper.py,
    customsortfiltermodel.py and simplewidgetmapper.py item view examples from
    Hans-Peter Jansen.
  - Added the IPC examples from Hans-Peter Jansen.
  - Added the WebKit examples from Hans-Peter Jansen.
  - Added the calendarwidget.py, stylesheet.py and textedit.py examples from
    Hans-Peter Jansen.
  - Added the --no-timestamp option to configure.py.
  - Added the lang example from Hans-Peter Jansen to the contrib directory.
  - The support for the detection of the destruction by Qt of internally
    constructed QObject instances (added in PyQt v4.7.5) has been disabled
    until a reliable thread-safe solution can be found.
  - Bug fixes.
  - Support for the QT_BEGIN_NAMESPACE and QT_END_NAMESPACE macros to allow
    PyQt to be built against Qt built with namespace support.
  - Bug fixes.
* Mon Oct 25 2010 dmueller@suse.de
- update to 4.8:
  - Added support for Qt v4.7 including the new QtDeclarative module.
  - pyqtProperty() can now be used as a method decorator in the same way that
  the standard Python property type can be used.
  - Added the notify argument to pyqtProperty().
  - Unbound signals can now be subscripted in the same way that bound signals
  can.
  - Added the missing << operator to QPolygon, QPolygonF and
  QXmlStreamAttributes.
  - PyQt will now automatically keep a reference to objects set with some sort
  of setter method when Qt expects the underlying C++ instance to stay valid
  but does not take ownership of it.
  - Added the lightmaps.py and stardelegate.py examples from Hans-Peter Jansen.
  - Added the --assume-shared option to configure.py.
  - The QtAssistant module is no longer built with Qt v4.7 and later.
* Tue Oct  5 2010 wstephenson@novell.com
- Add patch to fix python-kde4 build from kde-packagers@kde.org
* Fri Oct  1 2010 einar@heavensinferno.net
- update to 4.7.7:
  - - A bug fix release.
* Wed Sep  1 2010 dmueller@suse.de
- update to 4.7.5:
  - Added QStringRef.__str__() and QStringRef.__unicode__() to the QString v1
    API.
  - The destruction by Qt of internally constructed QObject instances is now
    automatically detected.
  - A signal defined with pyqtSignal() can now be used with methods that make
    an internal call to QObject::connect(), e.g. QTimer.singleShot().
  - Added the --from-imports command line argument to pyuic4 and the
    from_imports argument to PyQt4.uic.compileUi().
  - Added support for Python v3.2.
  - The Windows installer now includes qcollectiongenerator.exe and
    qhelpgenerator.exe.
  - Any class with a count() method now supports the len() builtin.
  - Added the missing == and != operators to QItemSelection.
  - Added readQVariantHash(), readQVariantList(), readQVariantMap,
    writeQVariantHash(), writeQVariantList() and writeQVariantMap() to
    QDataStream.
  - Added the ErrorPageExtensionOption and ErrorPageExtensionReturn classes,
    and the ErrorDomain enum to QWebPage.
* Tue Jun  8 2010 dmueller@suse.de
- update to 4.7.3:
  - Added evaluateToString() and evaluateToStringList() to QXmlQuery.
* Thu May 20 2010 cmorve69@yahoo.es
- Fixed build-compare
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.7.2:
  - A bug fix release.
  - Added the schema.py example.
  - Added the missing pushContext() and popContext() to QScriptEngine.
  - A QStyleOption instance will be wrapped as a specific sub-class where
    possible.
* Fri Jan 15 2010 tittiatcoke@gmail.com
- update to 4.7
  * Qt v4.6 is fully supported.
  * Added the QtMultimedia module.
  * Added keyword support for optional arguments.
  * Added docstrings for all classes, functions and methods that
    describe the Python signatures of all callables.
  * Any Python object that can be pickled can now be automatically
    written to and read from QSettings.
  * A QHostAddress.SpecialAddress can be used whenever a QHostAddress
    is expected.
  * Added the optional initialFilter argument to the
    QFileDialog.get*AndFilter() functions.
  * Added the readInt(), readQString(), readQStringList(), readQVariant(),
    writeInt(), writeQString(), writeQStringList() and writeQVariant()
    methods to QDataStream.
  * Added widgetPluginPath to the uic module to specify the directories
    that are searched for widget plugins.
  * Added the anchorlayout.py, animatedtiles.py, appchooser.py, easing.py,
    lighting.py, moveblocks.py, states.py and stickman.py examples.
  * Significantly reduced the size of the modules on Linux and MacOS/X.
* Fri Nov 20 2009 dmueller@suse.de
- update to 4.6.2:
  * A bug fix release.
* Fri Nov 20 2009 dmueller@suse.de
- add split-provides
* Sat Oct 24 2009 dmueller@suse.de
- update to 4.6.1:
  * Added the missing setDropAction() method to QGraphicsSceneDragDropEvent.
  * Added the QMacCocoaViewContainer class on OS/X.
  * An updated sandbox.py from Mark Summerfield.
* Mon Sep 28 2009 dmueller@suse.de
- update to 4.6:
  * alternate, more Pythonic, APIs have been defined
  * Qt properties can be initialised using keyword
  arguments passed when creating an instance
  * signals can be connected using keyword arguments passed
  when creating an instance
  * the QObject.pyqtConfigure() method has been added to set
  Qt properties and connect signals using keyword
  arguments at any time
  * Python v2.6 and later allow a Python bytearray to be
  used whenever a QByteArray is expected
  * the getOpenFileNameAndFilter(), getOpenFileNamesAndFilter()
  and getSaveFileNameAndFilter() static methods have been
  added to QFileDialog
  * a QLatin1String can be passed whenever a QString is expected
  * the compileUiDir() function has been added to the uic module.
* Tue Aug 18 2009 aj@suse.de
- use new python macros.
- Remove check for SUSE Linux 9.1.
* Wed Aug  5 2009 hpj@urpla.net
- use configure switch to always install the api file
* Thu Jul 30 2009 hpj@urpla.net
- update to 4.5.4 release, bugfixes and
  - Fixed a problem where None wasn't being interpreted as an invalid QVariant.
  - QVariant.toPyObject() now recurses through any collections.
  - Fixed the super-type of QGLContext because it takes part in parent/child
    relationships.
* Tue Jul 14 2009 beineri@opensuse.org
- update to 4.5.2 release, bugfixes and
  * support for the two QImage constructors that operate on non-
    const data by allowing a sip.voidptr to be passed
  * support for QHeaderView in pyuic4
  * any Python object can now be passed where a QVariant is
    expected, and None is interpreted as an invalid QVariant
* Mon Jul  6 2009 hpj@urpla.net
- create a separated -devel package
- install Qt designer plugin
- include the nice documentation
* Sun Jul  5 2009 dmueller@novell.com
- only use the configuration fix from trunk
* Wed Jul  1 2009 beineri@opensuse.org
- add trunk diff to fix build with Qt 4.5.2
* Wed Jun 17 2009 dmueller@suse.de
- update to 4.5.1:
  - Added the setCoordinateMode() and coordinateMode() methods to QGradient.
* Mon Jun  8 2009 beineri@opensuse.org
- update to 4.5 release:
  * support for Python v3 and Qt v4.5.1
  * new Pythonic API for connecting signals and slots
  * port of the current Qt examples launcher
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.5 snapshot 20090601 to fix support with
  newer python-sip
* Sun May 17 2009 beineri@opensuse.org
- update to 4.5 snapshot as of 20090507
* Thu May 14 2009 dmueller@suse.de
- require at least the exact qt version it was built against
* Fri Mar  6 2009 coolo@suse.de
- link the modules against python libraries
* Fri Dec  5 2008 dmueller@suse.de
- update to 4.4.4:
  - QVariant.toPyObject() will now handle any Python object.  The way in which
    QVariant wraps objects has subtlely changed in that the name returned by
    typeName() may now be different, but is now more consistent.
  - Added the data() method to the QPolygon, QPolygonF and QXmlAttributes
    classes.
  - Added the --no-designer-plugin option to configure.py to disable the
    building of the Python plugin for Qt Designer.
  - Added the missing Windows and Mac versions to QSysInfo.
* Sun Aug 10 2008 dmueller@suse.de
- update to 4.4.3:
  * a QChar can now be used whenever a QString is expected
  * all read related methods that take a maximum read length
  will now raise an exception if the length is negative
  * QVariant constructor that took a QVariantList argument
  has been replaced
  * QVariant constructor that took a QVariantMap argument
  has been replaced
  * added the embeddeddialogs.py and padnavigator.py examples
  from Igor Prischepoff
* Mon Jun 30 2008 dmueller@suse.de
- Factory merge (bnc#402524)
* Sat Jun 21 2008 mstopka@opensuse.org
- libQtWebKit support added
* Tue May 27 2008 dmueller@suse.de
- update to 4.4.2:
  * Major bugfixes, working bindings for Qt 4.4.0
* Wed Mar 19 2008 dmueller@suse.de
- fix wrong requires for 10.2
* Tue Feb 19 2008 dmueller@suse.de
- fix build against older distributions
* Thu Dec 13 2007 dmueller@suse.de
- bindings updated to Qt 4.3.3
* Sat Aug 11 2007 dmueller@suse.de
- fix requires (#297650)
* Fri Aug  3 2007 dmueller@suse.de
- update to 4.3:
  * bindings updated to match Qt 4.3.0
* Sat Apr 14 2007 dmueller@suse.de
- fix build against newer Qt
* Thu Apr 12 2007 dmueller@suse.de
- Update to 4.2:
  * bindings updated to match Qt 4.2.0
* Thu Apr  5 2007 dmueller@suse.de
- build against Qt 4.3
* Fri Jan 26 2007 dmueller@suse.de
- Initial package (4.1.1)
